﻿Imports System
Imports System.ComponentModel
Imports System.Drawing
Imports Wisej.Web

Namespace WisejResizeUploadSample
    Public Class ImageUpload
        Inherits Upload

        ''' <summary>
        ''' Returns or sets the size of the uploaded image.
        ''' </summary>
        <DefaultValue(GetType(Size), "")>
        Public Property ImageSize As Size
            Get
                Return _imageSize
            End Get
            Set(ByVal value As Size)

                If _imageSize <> value Then
                    _imageSize = value
                    MyBase.Update()
                End If
            End Set
        End Property

        Private _imageSize As Size


        ''' <summary>
        ''' Returns or sets the image format. The default is "image/png".
        ''' </summary>
        <DefaultValue("image/png")>
        Public Property MimeType As String
            Get
                Return _mimeType
            End Get
            Set(ByVal value As String)
                If String.IsNullOrEmpty(value) Then Throw New ArgumentNullException(NameOf(ImageUpload.MimeType))

                If _mimeType IsNot value Then
                    _mimeType = value
                    MyBase.Update()
                End If
            End Set
        End Property

        Private _mimeType As String = "image/png"



        ''' <summary>
        ''' Returns or sets a number between 0 and 1 indicating image quality if 
        ''' the requested type is "image/jpeg" or "image/webp".
        ''' </summary>
        <DefaultValue(1)>
        Public Property Quality As Single
            Get
                Return _quality
            End Get
            Set(ByVal value As Single)
                If value < 0 OrElse value > 1 Then Throw New ArgumentOutOfRangeException(NameOf(ImageUpload.Quality))

                If _quality <> value Then
                    _quality = value
                    MyBase.Update()
                End If
            End Set
        End Property

        Private _quality As Single = 1

        Protected Overrides Sub OnWebRender(ByVal config As dynamic)
            MyBase.OnWebRender(CObj(config))
            config.className = "wisej.web.ext.ImageUpload"
            config.imageSize = ImageSize
            config.mimeType = MimeType
            config.quality = Quality
        End Sub
    End Class
End Namespace
